@@ -1,7 +1,7 @@
 # Computation of MEWMA ARLs (multivariate mean monitoring)
-mewma.arl <- function(l, c, p, delta=0, hs=0, r=20, ntype=NULL, qm0=20, qm1=qm0) {
+mewma.arl <- function(l, cE, p, delta=0, hs=0, r=20, ntype=NULL, qm0=20, qm1=qm0) {
   if ( l<=0 | l>1 )		stop("l has to be between 0 and 1")
-  if ( c<=0 )			stop("threshold c has to be positive")
+  if ( cE<=0 )			stop("threshold c has to be positive")
   if ( p<1 )			stop("wrong dimension parameter")
   if ( delta<0 )		stop("wrong magnitude value")
   if ( hs<0 )			stop("wrong head start value")
@@ -13,7 +13,8 @@ mewma.arl <- function(l, c, p, delta=0, hs=0, r=20, ntype=NULL, qm0=20, qm1=qm0)
     if ( delta <1e-10 ) {
       ntype <- "gl2"
     } else {
-      if ( p %in% c(2,4) ) {
+      #if ( p %in% c(2,4) ) {
+      if ( p==2 ) {
         ntype <- "gl3"
       } else {
         ntype <- "gl5"
@@ -24,7 +25,7 @@ mewma.arl <- function(l, c, p, delta=0, hs=0, r=20, ntype=NULL, qm0=20, qm1=qm0)
   qtyp <- pmatch(tolower(ntype), c("gl", "co", "ra", "cc", "mc", "sr", "co2", "gl2", "gl3", "gl4", "gl5", "co3", "co4")) - 1
   if ( is.na(qtyp) )		stop("invalid type of numerical algorithm")
 
-  arl <- .C("mewma_arl", as.double(l), as.double(c),
+  arl <- .C("mewma_arl", as.double(l), as.double(cE),
                          as.integer(p), as.double(delta),
                          as.double(hs), as.integer(r),
                          as.integer(qtyp), as.integer(qm0), as.integer(qm1),
